@@ -26,6 +26,7 @@ from dataquality.utils.spacy_integration import (
     convert_spacy_ents_for_doc_to_predictions,
     convert_spacy_ner_logits_to_valid_logits,
     validate_obj,
+    validate_spacy_is_not_using_gpu,
     validate_spacy_version,
 )
 
@@ -89,6 +90,7 @@ def watch(nlp: Language) -> None:
     :return: None
     """
     validate_spacy_version()
+    validate_spacy_is_not_using_gpu()
     if not (config.current_project_id and config.current_run_id):
         raise GalileoException(
             "You must initialize dataquality first! "
@@ -146,8 +148,7 @@ def unwatch(nlp: Language) -> None:
 
     # Spacy does not expose an easy way to add a pipeline component from an existing
     # one, so we use the internal nlp methods from `nlp.add_pipe` for it
-    pipe_component = galileo_ner.__wrapped__
-    pipe_component.model = galileo_ner._self_old_model
+    pipe_component = galileo_ner._self_get_unwrapt()
     factory_name = "ner"
     name = factory_name  # for consistency with spacy code
 
@@ -183,9 +184,12 @@ class GalileoEntityRecognizer(CallableObjectProxy):
                 f"expects a beam width of 1 (the 'ner' default)."
             )
 
-        self._self_old_model = ner.model.copy()
         ner.model = GalileoTransitionBasedParserModel(ner.model)
 
+    def _self_get_unwrapt(self) -> EntityRecognizer:
+        self.__wrapped__.model = self.__wrapped__.model._self_get_unwrapt()
+        return self.__wrapped__
+
     def greedy_parse(self, docs: List[Doc], drop: float = 0.0) -> List:
         """Python-land implementation of the greedy_parse method in the ner component
 
@@ -292,6 +296,10 @@ class ThincModelWrapper(CallableObjectProxy):
         # https://github.com/python/mypy/issues/2427
         model._func = self._self_forward  # type: ignore
 
+    def _self_get_unwrapt(self) -> thinc.model.Model:
+        self.__wrapped__._func = self._self_orig_forward
+        return self.__wrapped__
+
     def _self_forward(
         self, model: thinc.model.Model, X: Any, is_train: bool
     ) -> Tuple[Any, Any]:
@@ -320,7 +328,7 @@ class GalileoTransitionBasedParserModel(ThincModelWrapper):
         parser_step_model, backprop_fn = self._self_orig_forward(
             model, X, is_train=is_train
         )
-
+        validate_spacy_is_not_using_gpu()
         model_logger = TextNERModelLogger()
         if model_logger.logger_config.cur_split == Split.inference:
             warnings.warn(
